li t0,0
li t1,1
li t3,0x7fffffff
loop:
add t2,t1,t0
mv t0,t1
mv t1,t2
li a7,1
mv a0,t0
ecall
li a7,11
li a0,0x0a
ecall
bltu t2,t3,loop

li a0,0xa
li a7,11
ecall
li a7,1
rdinstret a0
ecall
la a0,instructions
li a7,4
ecall

li a7,10
ecall

instructions: .asciz " instructions\n"
