/* Menu Thing for RVController - Screensaver
 * A product of Advanced Mesecons Devices, a Cheapie Systems company
 * This is free and unencumbered software released into the public domain.
 * See http://unlicense.org/ for more information */

void runScreensaver(void);
